@@ -4,62 +4,67 @@
 #' curve (gSGC) assumption proposed by Li et al., 2015 for OSL dating of sedimentary quartz
 #'
 #' The error of the De value is determined using a Monte Carlo simulation approach.
-#' Solving of the equation is realised using \code{\link{uniroot}}.
-#' Large values for \code{n.MC} will significantly increase the computation time.
+#' Solving of the equation is realised using [uniroot].
+#' Large values for `n.MC` will significantly increase the computation time.
 #'
 #'
-#' @param data \code{\link{data.frame}} (\bold{required}): input data of providing the following
-#' columns: 'LnTn', 'LnTn.error', Lr1Tr1', 'Lr1Tr1.error', 'Dr1'
-#' Note: column names are not required. The function expect the input data in the given order
+#' @param data [data.frame] (**required**): 
+#' input data of providing the following columns: *'LnTn', 'LnTn.error', Lr1Tr1', 'Lr1Tr1.error', 'Dr1'*
+#' **Note:** column names are not required. The function expect the input data in the given order
 #'
-#' @param gSGC.type \code{\link{character}} (with default): define the function parameters that
+#' @param gSGC.type [character] (*with default*): 
+#' define the function parameters that
 #' should be used for the iteration procedure: Li et al., 2015 (Table 2)
-#' presented function parameters for two dose ranges: \code{"0-450"} and \code{"0-250"}
+#' presented function parameters for two dose ranges: `"0-450"` and `"0-250"`
 #'
-#' @param gSGC.parameters \code{\link{list}} (optional): option to provide own function
-#' parameters used for #' fitting as named list.
-#' Nomenclature follows Li et al., 2015, i.e.
-#' \code{list(A,A.error,D0,D0.error,c,c.error,Y0,Y0.error,range)}, range requires a vector for
-#' the range the function is considered as valid, e.g. \code{range = c(0,250)}\cr
+#' @param gSGC.parameters [list] (*optional*): 
+#' option to provide own function parameters used for fitting as named list.
+#' Nomenclature follows Li et al., 2015, i.e. `list(A,A.error,D0,D0.error,c,c.error,Y0,Y0.error,range)`,
+#' range requires a vector for the range the function is considered as valid, e.g. `range = c(0,250)`\cr
 #' Using this option overwrites the default parameter list of the gSGC, meaning the argument
-#' \code{gSGC.type} will be without effect
+#' `gSGC.type` will be without effect
 #'
-#' @param n.MC \code{\link{integer}} (with default): number of Monte Carlo simulation runs for
-#' error estimation, s. details.
+#' @param n.MC [integer] (*with default*): 
+#' number of Monte Carlo simulation runs for error estimation, see details.
 #'
-#' @param verbose \code{\link{logical}}: enable or disable terminal output
+#' @param verbose [logical]: 
+#' enable or disable terminal output
 #'
-#' @param plot \code{\link{logical}}: enable or disable graphical feedback as plot
+#' @param plot [logical]: 
+#' enable or disable graphical feedback as plot
 #'
 #' @param ... parameters will be passed to the plot output
 #'
-#' @return Returns an S4 object of type \code{\linkS4class{RLum.Results}}.\cr
+#' @return Returns an S4 object of type [RLum.Results-class].
 #'
-#' \bold{@data}\cr
-#' $ De.value (data.frame) \cr
-#'  .. $ De  \cr
-#'  .. $ De.error \cr
-#'  .. $ Eta \cr
-#' $ De.MC (list) contains the matricies from the error estimation.\cr
-#' $ uniroot (list) contains the uniroot outputs of the De estimations\cr
+#' **`@data`**\cr
+#' `$ De.value` ([data.frame]) \cr
+#'  `.. $ De`  \cr
+#'  `.. $ De.error` \cr
+#'  `.. $ Eta` \cr
+#' `$ De.MC` ([list]) contains the matricies from the error estimation.\cr
+#' `$ uniroot` ([list]) contains the uniroot outputs of the De estimations\cr
 #'
-#' \bold{@info}\cr
-#' $ call (call) the original function call
+#' **`@info`**\cr
+#' `$ call`` ([call]) the original function call
 #'
 #'
 #' @section Function version: 0.1.1
 #'
-#' @author Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montagine (France)\cr
+#' @author 
+#' Sebastian Kreutzer, IRAMAT-CRP2A, Universite Bordeaux Montagine (France)
 #'
-#' @seealso \code{\linkS4class{RLum.Results}}, \code{\link{get_RLum}}, \code{\link{uniroot}}
+#' @seealso [RLum.Results-class], [get_RLum], [uniroot]
 #'
-#' @references  Li, B., Roberts, R.G., Jacobs, Z., Li, S.-H., 2015. Potential of establishing
+#' @references  
+#' Li, B., Roberts, R.G., Jacobs, Z., Li, S.-H., 2015. Potential of establishing
 #' a 'global standardised growth curve' (gSGC) for optical dating of quartz from sediments.
 #' Quaternary Geochronology 27, 94-104. doi:10.1016/j.quageo.2015.02.011
 #'
 #' @keywords datagen
 #'
 #' @examples
+#' 
 #' results <- calc_gSGC(data = data.frame(
 #' LnTn =  2.361, LnTn.error = 0.087,
 #' Lr1Tr1 = 2.744, Lr1Tr1.error = 0.091,
@@ -67,6 +72,7 @@
 #'
 #' get_RLum(results, data.object = "De")
 #'
+#' @md
 #' @export
 calc_gSGC<- function(
   data,
@@ -147,7 +153,7 @@ calc_gSGC<- function(
     }
 
     ##Define size of output objects
-    output.data <- data.table(
+    output.data <- data.table::data.table(
       DE = numeric(length = nrow(data)),
       DE.ERROR =  numeric(length = nrow(data)),
       ETA =  numeric(length = nrow(data))
